@@ -2,7 +2,6 @@ package gofish
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"testing"
@@ -573,154 +572,6 @@ func TestRunPipeNoBuilds(t *testing.T) {
 	require.False(t, client.CreatedFile)
 }
 
-func TestRunPipeMultipleArchivesSameOsBuild(t *testing.T) {
-	ctx := context.New(
-		config.Project{
-			Rigs: []config.GoFish{
-				{
-					Rig: config.RepoRef{
-						Owner: "test",
-						Name:  "test",
-					},
-				},
-			},
-		},
-	)
-
-	ctx.TokenType = context.TokenTypeGitHub
-	f, err := ioutil.TempFile(t.TempDir(), "")
-	require.NoError(t, err)
-	t.Cleanup(func() {
-		require.NoError(t, f.Close())
-	})
-
-	tests := []struct {
-		expectedError error
-		osarchs       []struct {
-			goos   string
-			goarch string
-			goarm  string
-		}
-	}{
-		{
-			expectedError: ErrMultipleArchivesSameOS,
-			osarchs: []struct {
-				goos   string
-				goarch string
-				goarm  string
-			}{
-				{
-					goos:   "darwin",
-					goarch: "amd64",
-				},
-				{
-					goos:   "darwin",
-					goarch: "amd64",
-				},
-			},
-		},
-		{
-			expectedError: ErrMultipleArchivesSameOS,
-			osarchs: []struct {
-				goos   string
-				goarch string
-				goarm  string
-			}{
-				{
-					goos:   "linux",
-					goarch: "amd64",
-				},
-				{
-					goos:   "linux",
-					goarch: "amd64",
-				},
-			},
-		},
-		{
-			expectedError: ErrMultipleArchivesSameOS,
-			osarchs: []struct {
-				goos   string
-				goarch string
-				goarm  string
-			}{
-				{
-					goos:   "linux",
-					goarch: "arm64",
-				},
-				{
-					goos:   "linux",
-					goarch: "arm64",
-				},
-			},
-		},
-		{
-			expectedError: ErrMultipleArchivesSameOS,
-			osarchs: []struct {
-				goos   string
-				goarch string
-				goarm  string
-			}{
-				{
-					goos:   "linux",
-					goarch: "arm",
-					goarm:  "6",
-				},
-				{
-					goos:   "linux",
-					goarch: "arm",
-					goarm:  "6",
-				},
-			},
-		},
-		{
-			expectedError: ErrMultipleArchivesSameOS,
-			osarchs: []struct {
-				goos   string
-				goarch string
-				goarm  string
-			}{
-				{
-					goos:   "linux",
-					goarch: "arm",
-					goarm:  "5",
-				},
-				{
-					goos:   "linux",
-					goarch: "arm",
-					goarm:  "6",
-				},
-				{
-					goos:   "linux",
-					goarch: "arm",
-					goarm:  "7",
-				},
-			},
-		},
-	}
-
-	for _, test := range tests {
-		for idx, ttt := range test.osarchs {
-			ctx.Artifacts.Add(&artifact.Artifact{
-				Name:   fmt.Sprintf("bin%d", idx),
-				Path:   f.Name(),
-				Goos:   ttt.goos,
-				Goarch: ttt.goarch,
-				Type:   artifact.UploadableArchive,
-				Extra: map[string]interface{}{
-					artifact.ExtraID:       fmt.Sprintf("foo%d", idx),
-					artifact.ExtraFormat:   "tar.gz",
-					artifact.ExtraBinaries: []string{"foo"},
-				},
-			})
-		}
-		client := client.NewMock()
-		require.Equal(t, test.expectedError, runAll(ctx, client))
-		require.False(t, client.CreatedFile)
-		// clean the artifacts for the next run
-		ctx.Artifacts = artifact.New()
-	}
-}
-
 func TestRunPipeBinaryRelease(t *testing.T) {
 	folder := t.TempDir()
 	ctx := &context.Context{
