@@ -13,8 +13,10 @@ import (
 // Pipe that signs docker images and manifests.
 type DockerPipe struct{}
 
-func (DockerPipe) String() string {
-	return "signing docker images"
+func (DockerPipe) String() string { return "signing docker images" }
+
+func (DockerPipe) Skip(ctx *context.Context) bool {
+	return ctx.SkipSign || len(ctx.Config.DockerSigns) == 0
 }
 
 // Default sets the Pipes defaults.
@@ -41,14 +43,6 @@ func (DockerPipe) Default(ctx *context.Context) error {
 
 // Publish signs and pushes the docker images signatures.
 func (DockerPipe) Publish(ctx *context.Context) error {
-	if ctx.SkipSign {
-		return pipe.ErrSkipSignEnabled
-	}
-
-	if ctx.SkipPublish {
-		return pipe.ErrSkipSignEnabled
-	}
-
 	g := semerrgroup.New(ctx.Parallelism)
 	for i := range ctx.Config.DockerSigns {
 		cfg := ctx.Config.DockerSigns[i]
@@ -64,7 +58,7 @@ func (DockerPipe) Publish(ctx *context.Context) error {
 					artifact.ByType(artifact.DockerImage),
 					artifact.ByType(artifact.DockerManifest),
 				))
-			case "none":
+			case "none": // TODO(caarlos0): remove this
 				return pipe.ErrSkipSignEnabled
 			default:
 				return fmt.Errorf("invalid list of artifacts to sign: %s", cfg.Artifacts)
